% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions-XCMSnExp.R
\name{featureSpectra}
\alias{featureSpectra}
\title{Extract spectra associated with features}
\usage{
featureSpectra(
  x,
  msLevel = 2L,
  expandRt = 0,
  expandMz = 0,
  ppm = 0,
  skipFilled = FALSE,
  return.type = c("MSpectra", "Spectra", "list", "List"),
  features = character(),
  ...
)
}
\arguments{
\item{x}{\link{XCMSnExp} object with feature defitions available.}

\item{msLevel}{\code{integer(1)} defining whether MS1 or MS2 spectra should be
returned. \code{msLevel = 1} is currently only supported for \code{return.type}
being \code{"Spectra"} or \code{"List"}.}

\item{expandRt}{\code{numeric(1)} to expand the retention time range of each
peak by a constant value on each side.}

\item{expandMz}{\code{numeric(1)} to expand the m/z range of each peak by a
constant value on each side.}

\item{ppm}{\code{numeric(1)} to expand the m/z range of each peak (on each side)
by a value dependent on the peak's m/z.}

\item{skipFilled}{\code{logical(1)} whether spectra for filled-in peaks should
be reported or not.}

\item{return.type}{\code{character(1)} defining the result type. Defaults to
\code{return.type = "MSpectra"} but \code{return.type = "Spectra"} or
\code{return.type = "List"} are preferred. See below for more information.}

\item{features}{\code{character}, \code{logical} or \code{integer} allowing to specify a
subset of features in \code{featureDefinitions} for which spectra should
be returned (providing either their ID, a logical vector same length
than \code{nrow(featureDefinitions(x))} or their index in
\code{featureDefinitions(x)}). This parameter overrides \code{skipFilled} and is
only supported for \code{return.type} being either \code{"Spectra"} or \code{"List"}.}

\item{...}{additional arguments to be passed along to \code{\link[=chromPeakSpectra]{chromPeakSpectra()}},
such as \code{method}.}
}
\value{
parameter \code{return.type} allow to specify the type of the returned object:
\itemize{
\item \code{return.type = "MSpectra"}: a \link{MSpectra} object with elements being
\linkS4class{Spectrum} objects. The result objects contains all spectra
for all features. Metadata column \code{"feature_id"} provides the ID of the
respective feature (i.e. its rowname in \code{\link[=featureDefinitions]{featureDefinitions()}}).
\item \code{return.type = "Spectra"}: a \code{Spectra} object (defined in the \code{Spectra}
package). The result contains all spectra for all features. Metadata column
\code{"feature_id"} provides the ID of the respective feature (i.e. its rowname
in \code{\link[=featureDefinitions]{featureDefinitions()}}.
\item \code{return.type = "list"}: \code{list} of \code{list}s that are either of length
0 or contain \linkS4class{Spectrum2} object(s) within the m/z-rt range. The
length of the list matches the number of features.
\item \code{return.type = "List"}: \code{List} of length equal to the number of
features with MS level \code{msLevel} is returned with elements being either
\code{NULL} (no spectrum found) or a \code{Spectra} object.
}
}
\description{
This function returns spectra associated with the identified features in the
input object. By default, spectra are returned for all features (from all
MS levels), but parameter \code{features} allows to specify selected features for
which the result should be returned.
Parameter \code{msLevel} allows to define whether MS level 1 or 2
spectra should be returned. For \code{msLevel = 1L} all MS1 spectra within the
retention time range of each chromatographic peak (in that respective data
file) associated with a feature are returned. Note that for samples in which
no peak was identified (or even filled-in) no spectra are returned.
For \code{msLevel = 2L} all MS2
spectra with a retention time within the retention time range and their
precursor m/z within the m/z range of any chromatographic peak of a feature
are returned. See also \code{\link[=chromPeakSpectra]{chromPeakSpectra()}} (used internally to extract
spectra for each chromatographic peak of a feature) for additional
information.

In contrast to the \code{\link[=chromPeakSpectra]{chromPeakSpectra()}} function, selecting a \code{method}
different than \code{"all"} will not return a single spectrum per feature, but
one spectrum per \strong{chromatographic peak} assigned to the feature.

Note also that \code{msLevel = 1L} is only supported for \code{return.type = "List"}
or \code{return.type = "Spectra"}.
}
\author{
Johannes Rainer
}
