% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions-XCMSnExp.R
\name{manualChromPeaks}
\alias{manualChromPeaks}
\alias{manualFeatures}
\title{Manual peak integration and feature definition}
\usage{
manualChromPeaks(
  object,
  chromPeaks = matrix(),
  samples = seq_along(fileNames(object)),
  BPPARAM = bpparam(),
  msLevel = 1L
)

manualFeatures(object, peakIdx = list(), msLevel = 1L)
}
\arguments{
\item{object}{\code{XCMSnExp} or \code{OnDiskMSnExp} object.}

\item{chromPeaks}{\code{matrix} defining the boundaries of the chromatographic
peaks, one row per chromatographic peak, columns \code{"mzmin"}, \code{"mzmax"},
\code{"rtmin"} and \code{"rtmax"} defining the m/z and retention time region of
each peak.}

\item{samples}{optional \code{integer} to select samples in which the peak
integration should be performed. By default performed in all samples.}

\item{BPPARAM}{parallel processing settings (see \code{\link[=bpparam]{bpparam()}} for details).}

\item{msLevel}{\code{integer(1)} defining the MS level in which peak integration
should be performed.}

\item{peakIdx}{for \code{nabbyakFeatyres}: \code{list} of \code{integer} vectors with the
indices of chromatographic peaks in the object's \code{chromPeaks} matrix
that should be grouped into features.}
}
\value{
\code{XCMSnExp} with the manually added chromatographic peaks or features.
}
\description{
The \code{manualChromPeaks} function allows to manually define chromatographic
peaks which are added to the object's \code{chromPeaks} matrix. In contrast to
\code{\link[=findChromPeaks]{findChromPeaks()}}, no \emph{peak detection} is performed (e.g. using an
algorithm such as \emph{centWave}) but the peak is added as defined by the user.
Note that a peak will not be added if no signal (intensity) was found in a
sample within the provided boundaries.

Because chromatographic peaks are added to eventually previously identified
peaks, it is suggested to run \code{\link[=refineChromPeaks]{refineChromPeaks()}} with the
\code{\link[=MergeNeighboringPeaksParam]{MergeNeighboringPeaksParam()}} approach to merge potentially overlapping
peaks.

The \code{manualFeatures} function allows to manually group identified
chromatographic peaks into features by providing their index in the
object's \code{chromPeaks} matrix.
}
\author{
Johannes Rainer
}
