% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions-Params.R, R/methods-XCMSnExp.R
\name{CleanPeaksParam}
\alias{CleanPeaksParam}
\alias{refineChromPeaks,XCMSnExp,CleanPeaksParam-method}
\alias{refineChromPeaks}
\alias{CleanPeaksParam-class}
\alias{show,CleanPeaksParam-method}
\title{Remove chromatographic peaks with too large rt width}
\usage{
CleanPeaksParam(maxPeakwidth = 10)

\S4method{refineChromPeaks}{XCMSnExp,CleanPeaksParam}(object, param = CleanPeaksParam(), msLevel = 1L)
}
\arguments{
\item{maxPeakwidth}{for \code{CleanPeaksParam}: \code{numeric(1)} defining the maximal
allowed peak width (in retention time).}

\item{object}{\link{XCMSnExp} object with identified chromatographic peaks.}

\item{param}{\code{CleanPeaksParam} object defining the settings for the method.}

\item{msLevel}{\code{integer} defining for which MS level(s) the chromatographic
peaks should be cleaned.}
}
\value{
\code{XCMSnExp} object with chromatographic peaks exceeding the specified
maximal retention time width being removed.
}
\description{
Remove chromatographic peaks with a retention time range larger than the
provided maximal acceptable width (\code{maxPeakwidth}).
}
\note{
\code{refineChromPeaks} methods will always remove feature definitions, because
a call to this method can change or remove identified chromatographic peaks,
which may be part of features.
}
\examples{

## Load a test data set with detected peaks
data(faahko_sub)
## Update the path to the files for the local system
dirname(faahko_sub) <- system.file("cdf/KO", package = "faahKO")

## Disable parallel processing for this example
register(SerialParam())

## Distribution of chromatographic peak widths
quantile(chromPeaks(faahko_sub)[, "rtmax"] - chromPeaks(faahko_sub)[, "rtmin"])

## Remove all chromatographic peaks with a width larger 60 seconds
data <- refineChromPeaks(faahko_sub, param = CleanPeaksParam(60))

quantile(chromPeaks(data)[, "rtmax"] - chromPeaks(data)[, "rtmin"])
}
\seealso{
Other chromatographic peak refinement methods: 
\code{\link{FilterIntensityParam}},
\code{\link{MergeNeighboringPeaksParam}}
}
\author{
Johannes Rainer
}
\concept{chromatographic peak refinement methods}
