% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions-Params.R, R/methods-XCMSnExp.R
\name{FilterIntensityParam}
\alias{FilterIntensityParam}
\alias{refineChromPeaks,XCMSnExp,FilterIntensityParam-method}
\alias{FilterIntensityParam-class}
\alias{show,FilterIntensityParam-method}
\title{Remove chromatographic peaks based on intensity}
\usage{
FilterIntensityParam(threshold = 0, nValues = 1L, value = "maxo")

\S4method{refineChromPeaks}{XCMSnExp,FilterIntensityParam}(
  object,
  param = FilterIntensityParam(),
  msLevel = 1L,
  BPPARAM = bpparam()
)
}
\arguments{
\item{threshold}{\code{numeric(1)} defining the minimal required intensity for
a peak to be retained. Defaults to \code{threshold = 0}.}

\item{nValues}{\code{integer(1)} defining the number of data points (per
chromatographic peak) that have to be \verb{>= threshold}. Defaults to
\code{nValues = 1}.}

\item{value}{\code{character(1)} specifying the column in \code{\link[=chromPeaks]{chromPeaks()}} that
should be used for the comparison. This is ignored for \code{nValues > 1}.}

\item{object}{\link{XCMSnExp} object with identified chromatographic peaks.}

\item{param}{\code{FilterIntensityParam} object defining the settings for
the method.}

\item{msLevel}{\code{integer(1)} defining the MS level in which peaks should be
filtered.}

\item{BPPARAM}{parameter object to set up parallel processing. Uses the
default parallel processing setup returned by \code{bpparam()}. See
\code{\link[=bpparam]{bpparam()}} for details and examples.}
}
\value{
\code{XCMSnExp} object with filtererd chromatographic peaks.
}
\description{
Remove chromatographic peaks with intensities below the specified threshold.
By default, with \code{nValues = 1}, all peaks with an intensity
\verb{>= threshold} are retained. Parameter \code{value} allows to specify the column of
the \code{\link[=chromPeaks]{chromPeaks()}} matrix that should be used for the filtering (defaults to
\code{value = "maxo"} and thus evaluating the maximal intensity for each peak).
With \code{nValues > 1} it is possible to keep only peaks that have \code{nValues}
intensities \verb{>= threshold}. Note that this requires data import from the
original MS files and run time of the call can thus be significantly larger.
Also, for \code{nValues > 1} parameter \code{value} is ignored.
}
\examples{

## Load a test data set with detected peaks
data(faahko_sub)
## Update the path to the files for the local system
dirname(faahko_sub) <- system.file("cdf/KO", package = "faahKO")

## Disable parallel processing for this example
register(SerialParam())

## Remove all peaks with a maximal intensity below 50000
res <- refineChromPeaks(faahko_sub, param = FilterIntensityParam(threshold = 50000))

nrow(chromPeaks(faahko_sub))
nrow(chromPeaks(res))

all(chromPeaks(res)[, "maxo"] > 50000)

## Keep only chromatographic peaks that have 3 signals above 20000; we
## perform this on the data of a single file.
xdata <- filterFile(faahko_sub)

res <- refineChromPeaks(xdata, FilterIntensityParam(threshold = 20000, nValues = 3))
nrow(chromPeaks(xdata))
nrow(chromPeaks(res))
}
\seealso{
Other chromatographic peak refinement methods: 
\code{\link{CleanPeaksParam}},
\code{\link{MergeNeighboringPeaksParam}}
}
\author{
Johannes Rainer, Mar Garcia-Aloy
}
\concept{chromatographic peak refinement methods}
